// Import modules from D3
import { getData } from './getData';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Variable declaration
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// Formatting the total value to show on the piechart
const xAxisTickFormat = number =>
  	format('.5~g')(number);
// Assigning data to the piechart
const render = (data) => {
  const pieData = pie().value(d=>d.totalvalue)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
      "#F20C0C",
      "#1ADED7",
      "#1A81DE",
      "#1E8449 ",
      "#C216CC",
      "#130E9B",
      "#00b5cc",
      "#CC1645",
      "#d9d5d5",
      "#CC7C16"
    ]);
 // Describing angles for pie chart 
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
//positioning pie chart   
  const sections = svg.append("g")
  	.attr("transform", `translate(250,220)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.totalvalue));
  
// positioning legends  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,50)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
// To get the shape of a circle adjacent  to coutries in legend  
  legend.append("circle")
    .attr("cx", 10)
    .attr("cy", function(d,i){ return 6 + i+1}) // 6 is where the first dot appears. 25 is the distance between dots
    .attr("r", 4.5)
  	.attr("fill", d => colors(d.data.totalvalue));
// Adding the country names as legend
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
// Adding the total value adjacent to the country names
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.totalvalue/1000))+"K");
}
// Parsing the data and caculating values in each row to sumup till 2019 year.
const run = async () => {
  let data = await getData()
  data.forEach(d=>{
    d.totalvalue = +d['2019'];
   
  });
 
	render(data);
};
run();